==> refcodes-io-1.9.9-sources.jar: org/refcodes/io/InputStreamConnectionByteReceiver.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.io;

import java.io.InputStream;
import java.net.ServerSocket;
import java.net.Socket;

/**
 * A {@link InputStreamConnectionByteReceiver} is a {@link DatagramReceiver}
 * connected through I/O streams with a {@link OutputStreamConnectionSender}. A
 * {@link Socket} or a {@link ServerSocket} may be used to retrieve the
 * according I/O streams.
 */
public interface InputStreamConnectionByteReceiver extends ConnectionByteReceiver<InputStream> {}

==> refcodes-io-3.3.8-sources.jar: org/refcodes/io/InputStreamConnectionByteReceiver.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.io;

import java.io.InputStream;
import java.net.ServerSocket;
import java.net.Socket;

/**
 * A {@link InputStreamConnectionByteReceiver} is a {@link DatagramReceiver}
 * connected through I/O streams with a
 * {@link OutputStreamConnectionDatagramsTransmitter}. A {@link Socket} or a
 * {@link ServerSocket} may be used to retrieve the according I/O streams.
 */
public interface InputStreamConnectionByteReceiver extends ConnectionBytesReceiver<InputStream> {}
